==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1.2-164-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1.2
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-2l8o5X5GhAA2dzJf3VVcp9

key:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-2l8o5X5GhAA2dzJf3VVcp9

license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  6af052d7cf474c9b2734ea8af6779e6c
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
    Prettyprinter.Convert.AnsiWlPprint

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-convert-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1.2-2l8o5X5GhAA2dzJf3VVcp9

depends:
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz
    ansi-wl-pprint-0.6.9-KQkMIu5Pvyg4BjyhslTItO base-4.16.4.0
    prettyprinter-1.7.1-4X811DzHwplE7Du7oIbLHM
    prettyprinter-ansi-terminal-1.1.3-IuN8x6IJGfYBDtUvUAjq23
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1.2-173-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prettyprinter-convert-ansi-wl-pprint
version:              1.1.2
visibility:           public
id:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-5zSrBxcq0rw6E14nWdlKJW

key:
    prettyprinter-convert-ansi-wl-pprint-1.1.2-5zSrBxcq0rw6E14nWdlKJW

license:              BSD-2-Clause
maintainer:
    Simon Jakobi <simon.jakobi@gmail.com>, David Luposchainsky <dluposchainsky at google>

author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.

description:          See README.md
category:             User Interfaces, Text
abi:                  90e08b1b92b7588ba61387193d43e59f
exposed:              True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
    Prettyprinter.Convert.AnsiWlPprint

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/prettyprinter-convert-ansi-wl-pprint-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-convert-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-convert-ansi-wl-pprint-1.1.2-5zSrBxcq0rw6E14nWdlKJW

depends:
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
    ansi-wl-pprint-0.6.9-9ctTtDT9IMdHR9rtwZQvOW base-4.16.4.0
    prettyprinter-1.7.1-6Wsg7uF6NF3C9EkVjlD5S1
    prettyprinter-ansi-terminal-1.1.3-8oO97RT2laQgzPfmsyMvY
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
